#!/bin/bash -x
#
# Script consists of Part 1 of the FDR job 
#  - Prefill
#  - Save "Before FDR" logs
#  - Metricss
#  - Repeatability1/2
#  - Persistence1
#  - SPC2 Pers-Write
#
#


#
# Configure Variable
#
if [ $# -ne 2 ]
then
	IOPS=360100
else
	IOPS=$1
fi

PERSIOPS=$(( $IOPS / 4 ))
INITIOPS=5000

ROOT=/home/spc1v3/fdr/fdrwork;export ROOT       # Absolute path of Work Directories
SCRIPTS=/home/spc1v3/fdr/07_Execution;export SCRIPTS	# main script directory
TUNING=/home/spc1v3/fdr/06_Tunables;export TUNING

# benchmark and misc commands
GETALLHOSTINFO="./getAllHostInfo.sh"
EXPORTLOG=exportLog.exp;export EXPORTLOG
EXPORTCFG=/home/spc1v3/fdr/04_Repository/cliS3n.exp;export EXPORTCFG


# create tmp directory for spc1v3 if it does not exist 
SPCTMP=/tmp/spc1v3;export SPCTMP
if [ ! -d ${SPCTMP} ]; then      
	mkdir ${SPCTMP}
fi
# create output directory for spc1v302/output 
mkdir /tmp/spc1v302
mkdir /tmp/spc1v302/output
ssh root@rx2 mkdir /tmp/spc1v302
ssh root@rx2 mkdir /tmp/spc1v302/output

#
# Create confID

#
confID=AF250S2_20170809S24;export confID

# obtain jobID based on the timestamp
# jobID uniquely identifies the benchmark run
jobID=JX`date +%y%m%d%H%M%S`;export jobID
WORKDIR=${ROOT}/${jobID};export WORKDIR		# WORK Directory

#
# save Variables Part 2 use
#
echo $ROOT > ${SPCTMP}/ROOT
echo $SCRIPTS > ${SPCTMP}/SCRIPTS
echo $confID > ${SPCTMP}/lastconfID
echo $jobID > ${SPCTMP}/lastjobID
echo $WORKDIR > ${SPCTMP}/WORKDIR
echo $EXPORTLOG > ${SPCTMP}/EXPORTLOG
echo $EXPORTCFG > ${SPCTMP}/EXPORTCFG
echo $PERSIOPS > ${SPCTMP}/PERSIOPS
echo $TUNING > ${SPCTMP}/TUNING

#
# setup the unique execution context(directory) for SPC1 job
#

# For Master host
cd ${ROOT}
mkdir ${jobID}
cd ${jobID}
# Copy the subdirectories to the new context 
cp -r ${ROOT}/../[01]*  .


echo -e AF250S2 "\n"  start time `date` "\n" | tee -a ${SPCTMP}/${jobID}_message.txt
echo -e  confID=$confID "\n" | tee -a ${SPCTMP}/${jobID}_message.txt
echo -e  jobID=$jobID "\n" | tee -a ${SPCTMP}/${jobID}_message.txt
echo "Starting AF250S2 FDR Job=${jobID}" | tee -a ${SPCTMP}/${jobID}_message.txt
#
#setuplinux
${TUNING}/setupLinux.sh
ssh root@rx2 /home/spc1v3/fdr/06_Tunables/setupLinux.sh

#
# Collect Server/HBA Information 
#
echo "Starting  Server/HBA Information  Collection Job=${jobID} at `date`" | tee -a ${SPCTMP}/${jobID}_message.txt
cd ${WORKDIR}
cd 10_Reference_Info 
${GETALLHOSTINFO}
cd ..
echo "Completed  Server/HBA Information  Collection Job=${jobID} at `date`" | tee -a ${SPCTMP}/${jobID}_message.txt

# Save Before F log

${SCRIPTS}/${EXPORTLOG} ${jobID} BeforeF
${EXPORTCFG} ssh af250s2 root 04_Repository/${jobID}_BeforeF.log
echo "Completed AF250S2 BeforeF log save Job=${jobID} at `date`" | tee -a ${SPCTMP}/${jobID}_message.txt


# Start Sequence of SPC1 benchmark jobs
#
cd ${WORKDIR}/09_Results
cp ${SCRIPTS}/SPC1.${confID}.asu ${SCRIPTS}/SPC1.${confID}.hst .
spc1 -master SPC1.${confID}.hst -run SPC1_INIT -iops ${INITIOPS} -storage SPC1.${confID}.asu 
spc1 -run SPC1_VERIFY -iops 100 -storage SPC1.${confID}.asu
spc1 -master SPC1.${confID}.hst -run SPC1_METRICS -iops ${IOPS} -storage SPC1.${confID}.asu
spc1 -run SPC1_VERIFY -iops 100 -storage SPC1.${confID}.asu
spc1 -master SPC1.${confID}.hst -run SPC1_PERSIST_1  -iops ${PERSIOPS} -storage SPC1.${confID}.asu

#
# Perform Power cycle
#
echo "Array is Ready for manual Power cycle Job=${jobID} at `date`" | tee -a ${SPCTMP}/${jobID}_message.txt
